'''Simple data loader module.

Loads data files from the "data" directory shipped with a game.

Enhancing this to handle caching etc. is left as an exercise for the reader.
'''

import os
import pygame

data_py = os.path.abspath(os.path.dirname(__file__))
data_dir = os.path.normpath(os.path.join(data_py, '..', 'data'))

def filepath(filename):
    '''Determine the path to a file in the data directory.
    '''
    return os.path.join(data_dir, filename)

def load(filename, mode='rb'):
    '''Open a file in the data directory.

    "mode" is passed as the second arg to open().
    '''
    return open(os.path.join(data_dir, filename), mode)

image_cache = {}
cursor_cache = {}

def load_image(filename):
    try:
        return image_cache[filename]
    except KeyError:
        img = pygame.image.load(load(filename), filename)
        img.convert()
        image_cache[filename] = img
        return img

def load_cursor(filename):
    try:
        return cursor_cache[filename]
    except KeyError:
        cfile = load(filename)
        name,ext = os.path.splitext(filename)
        mname = name + "-mask" + ext
        mfile = load(mname)
        cur = pygame.cursors.load_xbm(cfile,mfile)
        cursor_cache[filename] = cur
        return cur
